@@ -2,5 +2,4 @@ from WebAppDIRAC.Lib.WebHandler import WebHandler
 
 
 class ApplicationWizardHandler(WebHandler):
-
-    AUTH_PROPS = "authenticated"
+    DEFAULT_AUTHORIZATION = "authenticated"
