@@ -1,25 +1,23 @@
-import six
 import json
+import datetime
 
 from diraccfg import CFG
 
 from DIRAC import gConfig
 from DIRAC.ConfigurationSystem.Client.ConfigurationClient import ConfigurationClient
-from DIRAC.Core.Utilities import Time, List
+from DIRAC.Core.Utilities import List
 from DIRAC.ConfigurationSystem.private.Modificator import Modificator
 
-from WebAppDIRAC.Lib.WebHandler import WebSocketHandler, WErr, asyncGen
+from WebAppDIRAC.Lib.WebHandler import WebSocketHandler, WErr
 
 
 class ConfigurationManagerHandler(WebSocketHandler):
-
     AUTH_PROPS = "authenticated"
 
     def on_open(self):
         self.__configData = {}
 
-    @asyncGen
-    def on_message(self, msg):
+    def _on_message(self, msg):
         self.log.debug("RECEIVED", msg)
         try:
             params = json.loads(msg)
@@ -31,13 +29,13 @@ class ConfigurationManagerHandler(WebSocketHandler):
             self.log.info("Initialize force refresh..")
             res = gConfig.forceRefresh(fromMaster=True)
         if params["op"] == "init":
-            res = yield self.threadTask(self.__getRemoteConfiguration, "init")
+            res = self.__getRemoteConfiguration("init")
         elif params["op"] == "getSubnodes":
             res = self.__getSubnodes(params["node"], params["nodePath"])
         elif params["op"] == "showConfigurationAsText":
             res = self.__showConfigurationAsText()
         elif params["op"] == "resetConfiguration":
-            res = yield self.threadTask(self.__getRemoteConfiguration, "resetConfiguration")
+            res = self.__getRemoteConfiguration("resetConfiguration")
         elif params["op"] == "getBulkExpandedNodeData":
             res = self.__getBulkExpandedNodeData(params["nodes"])
         elif params["op"] == "setOptionValue":
@@ -57,7 +55,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
         elif params["op"] == "moveNode":
             res = self.__moveNode(params)
         elif params["op"] == "commitConfiguration":
-            res = yield self.threadTask(self.__commitConfiguration)
+            res = self.__commitConfiguration()
         elif params["op"] == "showCurrentDiff":
             res = self.__showCurrentDiff()
         elif params["op"] == "showshowHistory":
@@ -80,9 +78,8 @@ class ConfigurationManagerHandler(WebSocketHandler):
             url=gConfig.getValue("/DIRAC/Configuration/MasterServer", "Configuration/Server")
         )
         modCfg = Modificator(rpcClient)
-        retVal = modCfg.loadFromRemote()
 
-        if not retVal["OK"]:
+        if not modCfg.loadFromRemote()["OK"]:
             return {"success": 0, "op": "getSubnodes", "message": "The configuration cannot be read from the remote !"}
 
         self.__configData["cfgData"] = modCfg
@@ -93,25 +90,21 @@ class ConfigurationManagerHandler(WebSocketHandler):
         return {"success": 1, "op": funcName, "version": version, "name": configName}
 
     def __getSubnodes(self, parentNodeId, sectionPath):
-
         self.log.info("Expanding section", sectionPath)
 
         retData = []
-        retVal = self.__getSubnodesForPath(sectionPath, retData)
-
-        if not retVal:
-            return {"success": 0, "op": "getSubnodes", "message": "Section %s does not exist" % sectionPath}
+        if not self.__getSubnodesForPath(sectionPath, retData):
+            return {"success": 0, "op": "getSubnodes", "message": f"Section {sectionPath} does not exist"}
 
         return {"success": 1, "op": "getSubnodes", "nodes": retData, "parentNodeId": parentNodeId}
 
     def __getSubnodesForPath(self, sectionPath, retData):
-
         try:
             sectionCfg = self.__configData["cfgData"].getCFG()
             for section in [section for section in sectionPath.split("/") if not section.strip() == ""]:
                 sectionCfg = sectionCfg[section]
         except Exception as v:
-            self.log.exception("Section does not exist", "%s -> %s" % (sectionPath, repr(v)))
+            self.log.exception("Section does not exist", f"{sectionPath} -> {v!r}")
             return False
 
         for entryName in sectionCfg.listAll():
@@ -150,9 +143,8 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 continue
             commentLines.append(line)
         if commentLines or commiter:
-            return "%s<small><strong>%s</strong></small>" % ("<br/>".join(commentLines), commiter)
-        else:
-            return False
+            return f"{'<br/>'.join(commentLines)}<small><strong>{commiter}</strong></small>"
+        return False
 
     def __showConfigurationAsText(self):
         # time.sleep(10)
@@ -172,28 +164,28 @@ class ConfigurationManagerHandler(WebSocketHandler):
             optionPath = str(params["path"])
             optionValue = str(params["value"])
         except Exception as e:
-            return {"success": 0, "op": "setOptionValue", "message": "Can't decode path or value: %s" % str(e)}
+            return {"success": 0, "op": "setOptionValue", "message": "Can't decode path or value: {e}"}
 
         self.__setCommiter()
 
         self.__configData["cfgData"].setOptionValue(optionPath, optionValue)
 
         if self.__configData["cfgData"].getValue(optionPath) == optionValue:
-            self.log.info("Set option value", "%s = %s" % (optionPath, optionValue))
+            self.log.info("Set option value", f"{optionPath} = {optionValue}")
             return {"success": 1, "op": "setOptionValue", "parentNodeId": params["parentNodeId"], "value": optionValue}
-        return {"success": 0, "op": "setOptionValue", "message": "Can't update %s" % optionPath}
+        return {"success": 0, "op": "setOptionValue", "message": f"Can't update {optionPath}"}
 
     def __setComment(self, params):
         try:
             path = str(params["path"])
             value = str(params["value"])
         except Exception as e:
-            return {"success": 0, "op": "setComment", "message": "Can't decode path or value: %s" % str(e)}
+            return {"success": 0, "op": "setComment", "message": f"Can't decode path or value: {e}"}
 
         self.__setCommiter()
 
         self.__configData["cfgData"].setComment(path, value)
-        self.log.info("Set comment", "%s = %s" % (path, value))
+        self.log.info("Set comment", f"{path} = {value}")
         return {
             "success": 1,
             "op": "setComment",
@@ -206,7 +198,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             keyPath = str(params["path"]).strip()
             newName = str(params["newName"]).strip()
         except Exception as e:
-            return {"success": 0, "op": "renameKey", "message": "Can't decode parameter: %s" % str(e)}
+            return {"success": 0, "op": "renameKey", "message": f"Can't decode parameter: {e}"}
         try:
             if len(keyPath) == 0:
                 return {"success": 0, "op": "renameKey", "message": "Entity path is not valid"}
@@ -219,18 +211,16 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 self.__setCommiter()
                 if self.__configData["cfgData"].renameKey(keyPath, newName):
                     return {"success": 1, "op": "renameKey", "parentNodeId": params["parentNodeId"], "newName": newName}
-                else:
-                    return {"success": 0, "op": "renameKey", "message": "There was a problem while renaming"}
-            else:
-                return {"success": 0, "op": "renameKey", "message": "Path doesn't exist"}
+                return {"success": 0, "op": "renameKey", "message": "There was a problem while renaming"}
+            return {"success": 0, "op": "renameKey", "message": "Path doesn't exist"}
         except Exception as e:
-            return {"success": 0, "op": "renameKey", "message": "Can't rename entity: %s" % str(e)}
+            return {"success": 0, "op": "renameKey", "message": f"Can't rename entity: {e}"}
 
     def __deleteKey(self, params):
         try:
             keyPath = str(params["path"]).strip()
         except Exception as e:
-            return {"success": 0, "op": "deleteKey", "message": "Can't decode parameter: %s" % str(e)}
+            return {"success": 0, "op": "deleteKey", "message": f"Can't decode parameter: {e}"}
         try:
             if len(keyPath) == 0:
                 return {"success": 0, "op": "deleteKey", "message": "Entity path is not valid"}
@@ -238,10 +228,9 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 keyPath
             ):
                 return {"success": 1, "op": "deleteKey", "parentNodeId": params["parentNodeId"]}
-            else:
-                return {"success": 0, "op": "deleteKey", "message": "Entity doesn't exist"}
+            return {"success": 0, "op": "deleteKey", "message": "Entity doesn't exist"}
         except Exception as e:
-            return {"success": 0, "op": "deleteKey", "message": "Can't rename entity: %s" % str(e)}
+            return {"success": 0, "op": "deleteKey", "message": f"Can't rename entity: {e}"}
 
     def __createSection(self, params):
         try:
@@ -249,13 +238,13 @@ class ConfigurationManagerHandler(WebSocketHandler):
             sectionName = str(params["name"]).strip()
             configText = str(params["config"]).strip()
         except Exception as e:
-            return {"success": 0, "op": "createSection", "message": "Can't decode parameter: %s" % str(e)}
+            return {"success": 0, "op": "createSection", "message": f"Can't decode parameter: {e}"}
         try:
             if len(parentPath) == 0:
                 return {"success": 0, "op": "createSection", "message": "Parent path is not valid"}
             if len(sectionName) == 0:
                 return {"success": 0, "op": "createSection", "message": "Put any name for the section!"}
-            sectionPath = "%s/%s" % (parentPath, sectionName)
+            sectionPath = f"{parentPath}/{sectionName}"
             self.log.info("Creating section", sectionPath)
 
             self.__setCommiter()
@@ -270,7 +259,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 if htmlC:
                     qtipDict = {"text": htmlC}
                     nD["qtipCfg"] = qtipDict
-                #       If config Text is provided then a section is created out of that text
+                # If config Text is provided then a section is created out of that text
                 if configText != "":
                     cfgData = self.__configData["cfgData"].getCFG()
                     newCFG = CFG()
@@ -284,18 +273,16 @@ class ConfigurationManagerHandler(WebSocketHandler):
                         "node": nD,
                         "sectionFromConfig": 1,
                     }
-                else:
-                    return {
-                        "success": 1,
-                        "op": "createSection",
-                        "parentNodeId": params["parentNodeId"],
-                        "node": nD,
-                        "sectionFromConfig": 0,
-                    }
-            else:
-                return {"success": 0, "op": "createSection", "message": "Section can't be created. It already exists?"}
+                return {
+                    "success": 1,
+                    "op": "createSection",
+                    "parentNodeId": params["parentNodeId"],
+                    "node": nD,
+                    "sectionFromConfig": 0,
+                }
+            return {"success": 0, "op": "createSection", "message": "Section can't be created. It already exists?"}
         except Exception as e:
-            return {"success": 0, "op": "createSection", "message": "Can't create section: %s" % str(e)}
+            return {"success": 0, "op": "createSection", "message": f"Can't create section: {e}"}
 
     def __createOption(self, params):
         try:
@@ -303,7 +290,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             optionName = str(params["name"]).strip()
             optionValue = str(params["value"]).strip()
         except Exception as e:
-            return {"success": 0, "op": "createOption", "message": "Can't decode parameter: %s" % str(e)}
+            return {"success": 0, "op": "createOption", "message": f"Can't decode parameter: {e}"}
         try:
             if len(parentPath) == 0:
                 return {"success": 0, "op": "createOption", "message": "Parent path is not valid"}
@@ -313,12 +300,11 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 return {"success": 0, "op": "createOption", "message": "Options can't have a / in the name"}
             if len(optionValue) == 0:
                 return {"success": 0, "op": "createOption", "message": "Options should have values!"}
-            optionPath = "%s/%s" % (parentPath, optionName)
-            self.log.info("Creating option", "%s = %s" % (optionPath, optionValue))
+            optionPath = f"{parentPath}/{optionName}"
+            self.log.info("Creating option", f"{optionPath} = {optionValue}")
             if not self.__configData["cfgData"].existsOption(optionPath):
                 self.__setCommiter()
                 self.__configData["cfgData"].setOptionValue(optionPath, optionValue)
-
                 return {
                     "success": 1,
                     "op": "createOption",
@@ -327,10 +313,9 @@ class ConfigurationManagerHandler(WebSocketHandler):
                     "value": self.__configData["cfgData"].getValue(optionPath),
                     "comment": self.__configData["cfgData"].getComment(optionPath),
                 }
-            else:
-                return {"success": 0, "op": "createOption", "message": "Option can't be created. It already exists?"}
+            return {"success": 0, "op": "createOption", "message": "Option can't be created. It already exists?"}
         except Exception as e:
-            return {"success": 0, "op": "createOption", "message": "Can't create option: %s" % str(e)}
+            return {"success": 0, "op": "createOption", "message": f"Can't create option: {e}"}
 
     def __moveNode(self, params):
         try:
@@ -341,16 +326,14 @@ class ConfigurationManagerHandler(WebSocketHandler):
             return {
                 "success": 0,
                 "op": "moveNode",
-                "message": "Can't decode parameter: %s" % str(e),
+                "message": f"Can't decode parameter: {e}",
                 "nodeId": params["nodeId"],
                 "parentOldId": params["parentOldId"],
                 "parentNewId": params["parentNewId"],
                 "oldIndex": params["oldIndex"],
             }
 
-        self.log.info(
-            "Moving node", "Moving %s under %s before pos %s" % (nodePath, destinationParentPath, beforeOfIndex)
-        )
+        self.log.info("Moving node", f"Moving {nodePath} under {destinationParentPath} before pos {beforeOfIndex}")
         cfgData = self.__configData["cfgData"].getCFG()
 
         nodeDict = cfgData.getRecursive(nodePath)
@@ -366,7 +349,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             }
         oldParentDict = cfgData.getRecursive(nodePath, -1)
         newParentDict = cfgData.getRecursive(destinationParentPath)
-        if isinstance(newParentDict, six.string_types):
+        if isinstance(newParentDict, str):
             return {
                 "success": 0,
                 "op": "moveNode",
@@ -387,7 +370,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 "oldIndex": params["oldIndex"],
             }
         # Calculate the old parent path
-        oldParentPath = "/%s" % "/".join(List.fromChar(nodePath, "/")[:-1])
+        oldParentPath = f"/{'/'.join(List.fromChar(nodePath, '/')[:-1])}"
         if not oldParentPath == destinationParentPath and newParentDict["value"].existsKey(nodeDict["key"]):
             return {
                 "success": 0,
@@ -413,7 +396,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             return {
                 "success": 0,
                 "op": "moveNode",
-                "message": "Can't move node: %s" % str(e),
+                "message": f"Can't move node: {e}",
                 "nodeId": params["nodeId"],
                 "parentOldId": params["parentOldId"],
                 "parentNewId": params["parentNewId"],
@@ -434,7 +417,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             destinationParentPath = params["copyToPath"]
             newNodeName = params["newName"]
         except Exception as e:
-            return {"success": 0, "op": "copyKey", "message": "Can't decode parameter: %s" % str(e)}
+            return {"success": 0, "op": "copyKey", "message": f"Can't decode parameter: {e}"}
 
         #     gLogger.info( "Moving %s under %s before pos %s" % ( nodePath, destinationParentPath, beforeOfIndex ) )
         cfgData = self.__configData["cfgData"].getCFG()
@@ -446,12 +429,12 @@ class ConfigurationManagerHandler(WebSocketHandler):
         if not nodeDict:
             return {"success": 0, "op": "copyKey", "message": "Moving entity does not exist"}
         newParentDict = cfgData.getRecursive(destinationParentPath)
-        if isinstance(newParentDict, six.string_types):
+        if isinstance(newParentDict, str):
             return {"success": 0, "op": "copyKey", "message": "Destination is not a section"}
         if not newParentDict:
             return {"success": 0, "op": "copyKey", "message": "Destination does not exist"}
         # Calculate the old parent path
-        oldParentPath = "/%s" % "/".join(List.fromChar(nodePath, "/")[:-1])
+        oldParentPath = f"/{'/'.join(List.fromChar(nodePath, '/')[:-1])}"
         if not oldParentPath == destinationParentPath and newParentDict["value"].existsKey(newNodeName):
             return {"success": 0, "op": "copyKey", "message": "Another entry with the same name already exists"}
 
@@ -473,7 +456,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 addArgs["value"] = nodeDict["value"].clone()
                 newParentDict["value"].addKey(**addArgs)
         except Exception as e:
-            return {"success": 0, "op": "copyKey", "message": "Can't move node: %s" % str(e)}
+            return {"success": 0, "op": "copyKey", "message": f"Can't move node: {e}"}
         return {
             "success": 1,
             "op": "copyKey",
@@ -489,9 +472,8 @@ class ConfigurationManagerHandler(WebSocketHandler):
                 "op": "commitConfiguration",
                 "message": "You are not authorized to commit configurations!",
             }
-        self.log.always("User is commiting a new configuration version", "(%s)" % self.getUserDN())
-        retDict = self.__configData["cfgData"].commit()
-        if not retDict["OK"]:
+        self.log.always("User is commiting a new configuration version", f"({self.getUserDN()})")
+        if not (retDict := self.__configData["cfgData"].commit())["OK"]:
             return {"success": 0, "op": "commitConfiguration", "message": retDict["Message"]}
         return {"success": 1, "op": "commitConfiguration"}
 
@@ -562,7 +544,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             fromDate = str(params["fromVersion"])
             toDate = str(params["toVersion"])
         except Exception as e:
-            raise WErr(500, "Can't decode params: %s" % e)
+            raise WErr(500, f"Can't decode params: {e}")
         rpcClient = ConfigurationClient(
             url=gConfig.getValue("/DIRAC/Configuration/MasterServer", "Configuration/Server")
         )
@@ -576,7 +558,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
             "totalLines": processedData["totalLines"],
             "html": self.render_string(
                 "ConfigurationManager/diffConfig.tpl",
-                titles=("From version %s" % fromDate, "To version %s" % toDate),
+                titles=(f"From version {fromDate}", f"To version {toDate}"),
                 diffList=processedData["diff"],
             ).decode("utf-8"),
         }
@@ -588,22 +570,19 @@ class ConfigurationManagerHandler(WebSocketHandler):
         try:
             rollbackVersion = str(params["rollbackToVersion"])
         except Exception as e:
-            raise WErr(500, "Can't decode params: %s" % e)
+            raise WErr(500, f"Can't decode params: {e}")
         rpcClient = ConfigurationClient(
             url=gConfig.getValue("/DIRAC/Configuration/MasterServer", "Configuration/Server")
         )
-        modCfg = Modificator(rpcClient)
-        retVal = modCfg.rollbackToVersion(rollbackVersion)
-        if retVal["OK"]:
+        if (retVal := Modificator(rpcClient).rollbackToVersion(rollbackVersion))["OK"]:
             return {"success": 1, "op": "rollback", "version": rollbackVersion}
-        else:
-            return {"success": 0, "op": "rollback", "message": retVal["Value"]}
+        return {"success": 0, "op": "rollback", "message": retVal["Value"]}
 
     def __setCommiter(self):
-        commiter = "%s@%s - %s" % (
+        commiter = "{}@{} - {}".format(
             self.getUserName(),
             self.getUserGroup(),
-            Time.dateTime().strftime("%Y-%m-%d %H:%M:%S"),
+            datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S"),
         )
         self.__configData["cfgData"].commiterId = commiter
 
@@ -613,8 +592,7 @@ class ConfigurationManagerHandler(WebSocketHandler):
         rpcClient = ConfigurationClient(
             url=gConfig.getValue("/DIRAC/Configuration/MasterServer", "Configuration/Server")
         )
-        retVal = rpcClient.getCommitHistory()
-        if retVal["OK"]:
+        if (retVal := rpcClient.getCommitHistory())["OK"]:
             cDict = {"numVersions": 0, "versions": []}
             for entry in retVal["Value"]:
                 cDict["numVersions"] += 1
@@ -624,10 +602,9 @@ class ConfigurationManagerHandler(WebSocketHandler):
         return {"success": 1, "op": "showshowHistory", "result": cDict}
 
     def __download(self):
-
         version = str(self.__configData["cfgData"].getCFG()["DIRAC"]["Configuration"]["Version"])
         configName = str(self.__configData["cfgData"].getCFG()["DIRAC"]["Configuration"]["Name"])
-        fileName = "cs.%s.%s" % (configName, version.replace(":", "").replace("-", "").replace(" ", ""))
+        fileName = f"cs.{configName}.{version.replace(':', '').replace('-', '').replace(' ', '')}"
 
         return {"success": 1, "op": "download", "result": self.__configData["strCfgData"], "fileName": fileName}
 
