@@ -5,13 +5,14 @@ from DIRAC import gConfig, gLogger
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 from DIRAC.ConfigurationSystem.Client.Helpers.Registry import getVOForGroup
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
+from DIRAC.FrameworkSystem.Client.ProxyManagerClient import ProxyManagerClient
+from DIRAC.WorkloadManagementSystem.Client.WMSClient import WMSClient
 
-from WebAppDIRAC.Lib.WebHandler import WebHandler, asyncGen
+from WebAppDIRAC.Lib.WebHandler import WebHandler
 
 
 class JobLaunchpadHandler(WebHandler):
-
-    AUTH_PROPS = "authenticated"
+    DEFAULT_AUTHORIZATION = "authenticated"
     defaultParams = {
         "JobName": [1, "DIRAC"],
         "Executable": [1, "/bin/ls"],
@@ -35,8 +36,7 @@ class JobLaunchpadHandler(WebHandler):
         "ParameterFactor": [0, "0"],
     }
 
-    def __init__(self, *args, **kwargs):
-        super(JobLaunchpadHandler, self).__init__(*args, **kwargs)
+    def initializeRequest(self):
         for opt, value in (self.getAppSettings().get("Options") or {}).items():
             self.defaultParams[opt] = value.replace(", ", ",").split(",")
         self.user = self.getUserName()
@@ -44,11 +44,9 @@ class JobLaunchpadHandler(WebHandler):
         self.vo = getVOForGroup(self.group)
 
     def web_getProxyStatus(self):
-        self.finish(self.__getProxyStatus())
-
-    def __getProxyStatus(self, secondsOverride=None):
-        from DIRAC.FrameworkSystem.Client.ProxyManagerClient import ProxyManagerClient
+        return self.__getProxyStatus()
 
+    def __getProxyStatus(self):
         proxyManager = ProxyManagerClient()
 
         group = self.getUserGroup()
@@ -61,39 +59,12 @@ class JobLaunchpadHandler(WebHandler):
         defaultSeconds = 24 * 3600 + 60  # 24H + 1min
         validSeconds = gConfig.getValue("/Registry/DefaultProxyLifeTime", defaultSeconds)
 
-        gLogger.info("\033[0;31m userHasProxy(%s, %s, %s) \033[0m" % (userDN, group, validSeconds))
+        gLogger.info(f"\033[0;31m userHasProxy({userDN}, {group}, {validSeconds}) \033[0m")
 
-        result = proxyManager.userHasProxy(userDN, group, validSeconds)
+        if (result := proxyManager.userHasProxy(userDN, group, validSeconds))["OK"]:
+            return {"success": "true", "result": "true" if result["Value"] else "false"}
+        return {"success": "false", "error": "false"}
 
-        if result["OK"]:
-            if result["Value"]:
-                return {"success": "true", "result": "true"}
-            else:
-                return {"success": "true", "result": "false"}
-        else:
-            return {"success": "false", "error": "false"}
-
-        gLogger.info("\033[0;31m PROXY: \033[0m", result)
-
-    def __getPlatform(self):
-        gLogger.info("start __getPlatform")
-
-        path = "/Resources/Computing/OSCompatibility"
-        result = gConfig.getOptionsDict(path)
-
-        gLogger.debug(result)
-
-        if not result["OK"]:
-            return False
-
-        platformDict = result["Value"]
-        platform = list(platformDict)
-
-        gLogger.debug("platform: %s" % platform)
-        gLogger.info("end __getPlatform")
-        return platform
-
-    @asyncGen
     def web_getLaunchpadSetupWithLFNs(self):
         """Method obtain launchpad setup with pre-selected LFNs as input data parameter,
         the caller js client will use setup to open an new Launchpad
@@ -126,7 +97,7 @@ class JobLaunchpadHandler(WebHandler):
                 if sectionOptions["OK"]:
                     predefinedSets[section] = sectionOptions["Value"]
 
-        self.finish({"success": "true", "result": params, "predefinedSets": predefinedSets})
+        return {"success": "true", "result": params, "predefinedSets": predefinedSets}
 
     def web_getLaunchpadOpts(self):
         """Reading of the predefined sets of launchpad parameters values"""
@@ -140,18 +111,15 @@ class JobLaunchpadHandler(WebHandler):
                 pprint.pprint(sectionOptions)
                 if sectionOptions["OK"]:
                     predefinedSets[section] = sectionOptions["Value"]
-        self.finish({"success": "true", "result": self.defaultParams, "predefinedSets": predefinedSets})
+        return {"success": "true", "result": self.defaultParams, "predefinedSets": predefinedSets}
 
-    @asyncGen
     def web_jobSubmit(self):
         # self.set_header('Content-type', "text/html")  # Otherwise the browser would offer you to download a JobSubmit file
         if "NormalUser" not in self.getProperties():
-            self.finish({"success": "false", "error": "You are not allowed to run the jobs"})
-            return
-        proxy = yield self.threadTask(self.__getProxyStatus, 86460)
+            return {"success": "false", "error": "You are not allowed to run the jobs"}
+        proxy = self.__getProxyStatus()
         if proxy["success"] == "false" or proxy["result"] == "false":
-            self.finish({"success": "false", "error": "You can not run a job: your proxy is valid less then 24 hours"})
-            return
+            return {"success": "false", "error": "You can not run a job: your proxy is valid less then 24 hours"}
 
         jdl = ""
         lfns = []
@@ -179,16 +147,12 @@ class JobLaunchpadHandler(WebHandler):
                         if len(parameters) > 0:
                             jdl += str(item) + " = {" + parameters + "};"
                         else:
-                            self.finish({"success": "false", "error": "Parameters vector has zero length"})
-                            return
+                            return {"success": "false", "error": "Parameters vector has zero length"}
                     else:
-                        self.finish(
-                            {
-                                "success": "false",
-                                "error": "Parameters must be an integer or a vector. Example: 4 or {1,2,3,4}",
-                            }
-                        )
-                        return
+                        return {
+                            "success": "false",
+                            "error": "Parameters must be an integer or a vector. Example: 4 or {1,2,3,4}",
+                        }
             else:
                 jdl += str(item) + ' = "' + str(params[item]) + '";'
 
@@ -196,12 +160,12 @@ class JobLaunchpadHandler(WebHandler):
         for key in self.request.files:
             try:
                 if self.request.files[key][0].filename:
-                    gLogger.info("\033[0;31m file - %s \033[0m " % self.request.files[key][0].filename)
+                    gLogger.info(f"\x1b[0;31m file - {self.request.files[key][0].filename} \x1b[0m ")
                     store.append(self.request.files[key][0])
             except Exception:
                 pass
 
-        gLogger.info("\033[0;31m *** %s \033[0m " % params)
+        gLogger.info(f"\x1b[0;31m *** {params} \x1b[0m ")
 
         clearFS = False  # Clear directory flag
         fileNameList = []
@@ -227,7 +191,7 @@ class JobLaunchpadHandler(WebHandler):
                 exception_counter = 1
                 callback = {
                     "success": "false",
-                    "error": "An EXCEPTION happens during saving your sandbox file(s): %s" % str(x),
+                    "error": f"An EXCEPTION happens during saving your sandbox file(s): {str(x)}",
                 }
 
         sndBox = ""
@@ -236,19 +200,17 @@ class JobLaunchpadHandler(WebHandler):
 
         if exception_counter == 0:
             jdl += sndBox
-            from DIRAC.WorkloadManagementSystem.Client.WMSClient import WMSClient
-
             jobManager = WMSClient(useCertificates=True, timeout=1800)
             jdl = str(jdl)
             gLogger.info("J D L : ", jdl)
             try:
-                result = yield self.threadTask(jobManager.submitJob, jdl)
+                result = jobManager.submitJob(jdl)
                 if result["OK"]:
                     callback = {"success": "true", "result": result["Value"]}
                 else:
                     callback = {"success": "false", "error": result["Message"]}
             except Exception as x:
-                callback = {"success": "false", "error": "An EXCEPTION happens during job submittion: %s" % str(x)}
+                callback = {"success": "false", "error": f"An EXCEPTION happens during job submittion: {str(x)}"}
         if clearFS:
             shutil.rmtree(storePath)
-        self.finish(callback)
+        return callback
