@@ -3,28 +3,23 @@ import json
 import tempfile
 import datetime
 
-from hashlib import md5
-
 from DIRAC import gConfig, S_OK, S_ERROR, gLogger
-from DIRAC.Core.DISET.TransferClient import TransferClient
-from DIRAC.Core.Utilities import Time, List, DictCache
+from DIRAC.Core.Tornado.Client.ClientSelector import TransferClientSelector as TransferClient
+from DIRAC.Core.Utilities import TimeUtilities, List, DictCache
 from DIRAC.Core.Utilities.Plotting.FileCoding import extractRequestFromFileId, codeRequestInFileId
 from DIRAC.MonitoringSystem.Client.MonitoringClient import MonitoringClient
 
-from WebAppDIRAC.Lib.WebHandler import WebHandler, asyncGen
+from WebAppDIRAC.Lib.WebHandler import WebHandler, FileResponse
 
 
 class MonitoringHandler(WebHandler):
-
-    AUTH_PROPS = "authenticated"
+    DEFAULT_AUTHORIZATION = "authenticated"
     __keysCache = DictCache.DictCache()
 
     def __getUniqueKeyValues(self, typeName):
         cacheKey = (self.getUserName(), self.getUserGroup(), self.getUserSetup(), typeName)
-        data = MonitoringHandler.__keysCache.get(cacheKey)
-        if not data:
-            client = MonitoringClient()
-            retVal = client.listUniqueKeyValues(typeName)
+        if not (data := MonitoringHandler.__keysCache.get(cacheKey)):
+            retVal = MonitoringClient().listUniqueKeyValues(typeName)
             if "rpcStub" in retVal:
                 del retVal["rpcStub"]
             if not retVal["OK"]:
@@ -35,7 +30,7 @@ class MonitoringHandler(WebHandler):
                 siteLevel = {}
                 for siteName in retVal["Value"]["Site"]:
                     sitePrefix = siteName.split(".")[0].strip()
-                    level = gConfig.getValue("/Resources/Sites/%s/%s/MoUTierLevel" % (sitePrefix, siteName), 10)
+                    level = gConfig.getValue(f"/Resources/Sites/{sitePrefix}/{siteName}/MoUTierLevel", 10)
                     if level not in siteLevel:
                         siteLevel[level] = []
                     siteLevel[level].append(siteName)
@@ -47,15 +42,12 @@ class MonitoringHandler(WebHandler):
             MonitoringHandler.__keysCache.add(cacheKey, 300, data)
         return data
 
-    @asyncGen
-    def web_getSelectionData(self):
+    def web_getSelectionData(self, type, **kwargs):
+        typeName = type
         callback = {}
-        typeName = self.get_argument("type")
         # Get unique key values
-        retVal = yield self.threadTask(self.__getUniqueKeyValues, typeName)
-        if not retVal["OK"]:
-            self.finish({"success": "false", "result": "", "error": retVal["Message"]})
-            return
+        if not (retVal := self.__getUniqueKeyValues(typeName))["OK"]:
+            return {"success": "false", "result": "", "error": retVal["Message"]}
 
         records = {}
         for record in retVal["Value"]:  # may have more than 1000 of records.
@@ -63,27 +55,21 @@ class MonitoringHandler(WebHandler):
             length = len(retVal["Value"][record])
             if length > 10000:
                 records[record] = retVal["Value"][record][length - 5000 :]
-                message = (
-                    "The %s accounting type contains to many rows: %s - > %d. Note: Only 1000 rows are returned!"
-                    % (typeName, record, length)
-                )
+                message = f"The {typeName} monitoring type contains too many rows: {record} -> {length}"
+                message += " Note: Only 5000 rows are returned!"
                 gLogger.warn(message)
             else:
                 records[record] = retVal["Value"][record]
         callback["selectionValues"] = records
 
         # Cache for plotsList?
-        data = MonitoringHandler.__keysCache.get("reportsList:%s" % typeName)
-        if not data:
-            repClient = MonitoringClient()
-            retVal = yield self.threadTask(repClient.listReports, typeName)
-            if not retVal["OK"]:
-                self.finish({"success": "false", "result": "", "error": retVal["Message"]})
-                return
+        if not (data := MonitoringHandler.__keysCache.get(f"reportsList:{typeName}")):
+            if not (retVal := MonitoringClient().listReports(typeName))["OK"]:
+                return {"success": "false", "result": "", "error": retVal["Message"]}
             data = retVal["Value"]
-            MonitoringHandler.__keysCache.add("reportsList:%s" % typeName, 300, data)
+            MonitoringHandler.__keysCache.add(f"reportsList:{typeName}", 300, data)
         callback["plotsList"] = data
-        self.finish({"success": "true", "result": callback})
+        return {"success": "true", "result": callback}
 
     def __parseFormParams(self):
         pD = {}
@@ -91,9 +77,7 @@ class MonitoringHandler(WebHandler):
         pinDates = False
 
         for name in self.request.arguments:
-            if name.find("_") != 0:
-                continue
-            pD[name[1:]] = self.get_argument(name)
+            pD[name] = self.get_argument(name)
 
         # Personalized title?
         if "plotTitle" in pD:
@@ -118,13 +102,15 @@ class MonitoringHandler(WebHandler):
             return S_ERROR("Missing plot name!")
         reportName = pD["plotName"]
         del pD["plotName"]
+        if "lastSeconds" in pD:
+            extraParams["lastSeconds"] = pD.pop("lastSeconds")
         # Get times
         if "timeSelector" not in pD:
             return S_ERROR("Missing time span!")
         # Find the proper time!
         pD["timeSelector"] = int(pD["timeSelector"])
         if pD["timeSelector"] > 0:
-            end = Time.dateTime()
+            end = datetime.datetime.utcnow()
             start = end - datetime.timedelta(seconds=pD["timeSelector"])
             if not pinDates:
                 extraParams["lastSeconds"] = pD["timeSelector"]
@@ -132,18 +118,22 @@ class MonitoringHandler(WebHandler):
             if "endTime" not in pD:
                 end = False
             else:
-                end = Time.fromString(pD["endTime"])
+                end = TimeUtilities.fromString(pD["endTime"])
                 del pD["endTime"]
             if "startTime" not in pD:
                 return S_ERROR("Missing starTime!")
             else:
-                start = Time.fromString(pD["startTime"])
+                start = TimeUtilities.fromString(pD["startTime"])
                 del pD["startTime"]
         del pD["timeSelector"]
 
         for k in pD:
             if k.find("ex_") == 0:
                 extraParams[k[3:]] = pD[k]
+
+        # Selection data
+        data = {}
+
         # Listify the rest
         for selName in pD:
             if selName == "grouping":
@@ -154,69 +144,62 @@ class MonitoringHandler(WebHandler):
                 except ValueError:
                     pD[selName] = List.fromChar(pD[selName], ",")
 
+            # If json parse value as string, listify it
+            if isinstance(pD[selName], str):
+                pD[selName] = List.fromChar(pD[selName], ",")
+
+            # Convert 'value*' to list of values that starts with 'value'
+            fullList = []
+            for value in pD[selName]:
+                if value.endswith("*"):
+                    if not data:
+                        retVal = self.__getUniqueKeyValues(typeName)
+                        if not retVal["OK"]:
+                            return retVal
+                        data = retVal["Value"]
+                    for v in data[selName]:
+                        if v.startswith(value[:-1]):
+                            fullList.append(v)
+                else:
+                    fullList.append(value)
+
+            pD[selName] = fullList
+
         return S_OK((typeName, reportName, start, end, pD, grouping, extraParams))
 
-    @asyncGen
     def web_generatePlot(self):
-        callback = {}
-        retVal = yield self.threadTask(self.__queryForPlot)
-        if retVal["OK"]:
-            callback = {"success": True, "data": retVal["Value"]["plot"]}
-        else:
-            callback = {"success": False, "errors": retVal["Message"]}
-        self.finish(callback)
+        if (retVal := self.__queryForPlot())["OK"]:
+            return {"success": "true", "data": retVal["Value"]["plot"]}
+        return {"success": "false", "errors": retVal["Message"]}
 
     def __queryForPlot(self):
-        retVal = self.__parseFormParams()
-        if not retVal["OK"]:
-            return retVal
-        params = retVal["Value"]
-        repClient = MonitoringClient()
-        retVal = repClient.generateDelayedPlot(*params)
-        return retVal
+        res = self.__parseFormParams()
+        return MonitoringClient().generateDelayedPlot(*res["Value"]) if res["OK"] else res
 
-    @asyncGen
-    def web_getPlotImg(self):
-        """
-        Get plot image
-        """
-        callback = {}
-        if "file" not in self.request.arguments:
-            callback = {"success": "false", "error": "Maybe you forgot the file?"}
-            self.finish(callback)
-            return
-        plotImageFile = self.get_argument("file")
+    def web_getPlotImg(self, fileName=None):
+        """Get plot image"""
+        if not fileName:
+            return {"success": "false", "error": "Maybe you forgot the file?"}
         # Prevent directory traversal
-        plotImageFile = os.path.normpath("/" + plotImageFile).lstrip("/")
+        plotImageFile = os.path.normpath("/" + fileName).lstrip("/")
 
         transferClient = TransferClient("Monitoring/Monitoring")
         tempFile = tempfile.TemporaryFile()
-        retVal = yield self.threadTask(transferClient.receiveFile, tempFile, plotImageFile)
+        retVal = transferClient.receiveFile(tempFile, plotImageFile)
         if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
-            return
+            return {"success": "false", "error": retVal["Message"]}
         tempFile.seek(0)
         data = tempFile.read()
-        self.finishWithImage(data, plotImageFile)
+        return FileResponse(data, plotImageFile, ext="png")
 
-    @asyncGen
-    def web_getPlotImgFromCache(self):
-        """
-        Get plot image from cache.
-        """
-        callback = {}
-        if "file" not in self.request.arguments:
-            callback = {"success": "false", "error": "Maybe you forgot the file?"}
-            self.finish(callback)
-            return
-        plotImageFile = self.get_argument("file")
+    def web_getPlotImgFromCache(self, fileName=None):
+        """Get plot image from cache."""
+        if not fileName:
+            return {"success": "false", "error": "Maybe you forgot the file?"}
 
-        retVal = extractRequestFromFileId(plotImageFile)
+        retVal = extractRequestFromFileId(fileName)
         if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Value"]}
-            self.finish(callback)
-            return
+            return {"success": "false", "error": retVal["Message"]}
         fields = retVal["Value"]
         if "extraArgs" in fields:  # in order to get the plot from the cache we have to clean the extraArgs...
             plotTitle = ""
@@ -229,72 +212,48 @@ class MonitoringHandler(WebHandler):
 
         retVal = codeRequestInFileId(fields)
         if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Value"]}
-            self.finish(callback)
-            return
+            return {"success": "false", "error": retVal["Message"]}
         plotImageFile = retVal["Value"]["plot"]
 
         transferClient = TransferClient("Monitoring/Monitoring")
         tempFile = tempfile.TemporaryFile()
-        retVal = yield self.threadTask(transferClient.receiveFile, tempFile, plotImageFile)
-        if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
-            return
+        if not (retVal := transferClient.receiveFile(tempFile, plotImageFile))["OK"]:
+            return {"success": "false", "error": retVal["Message"]}
         tempFile.seek(0)
         data = tempFile.read()
-        self.finishWithImage(data, plotImageFile, disableCaching=True)
+        return FileResponse(data, plotImageFile, ext="png", cache=False)
 
-    @asyncGen
     def web_getCsvPlotData(self):
-        callback = {}
-        retVal = self.__parseFormParams()
-        if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
+        if not (retVal := self.__parseFormParams())["OK"]:
+            return {"success": "false", "error": retVal["Message"]}
         params = retVal["Value"]
-        repClient = MonitoringClient()
-        retVal = yield self.threadTask(repClient.getReport, *params)
-        if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
+        if not (retVal := MonitoringClient().getReport(*params))["OK"]:
+            return {"success": "false", "error": retVal["Message"]}
         rawData = retVal["Value"]
-        groupKeys = rawData["data"].keys()
-        groupKeys.sort()
+        groupKeys = sorted(rawData["data"])
         if "granularity" in rawData:
             granularity = rawData["granularity"]
             data = rawData["data"]
-            tS = int(Time.toEpoch(params[2]))
+            tS = int(TimeUtilities.toEpoch(params[2]))
             timeStart = tS - tS % granularity
-            strData = "epoch,%s\n" % ",".join(groupKeys)
-            for timeSlot in range(timeStart, int(Time.toEpoch(params[3])), granularity):
+            strData = f"epoch,{','.join(groupKeys)}\n"
+            for timeSlot in range(timeStart, int(TimeUtilities.toEpoch(params[3])), granularity):
                 lineData = [str(timeSlot)]
                 for key in groupKeys:
                     if timeSlot in data[key]:
                         lineData.append(str(data[key][timeSlot]))
                     else:
                         lineData.append("")
-                strData += "%s\n" % ",".join(lineData)
+                strData += f"{','.join(lineData)}\n"
         else:
-            strData = "%s\n" % ",".join(groupKeys)
+            strData = f"{','.join(groupKeys)}\n"
             strData += ",".join([str(rawData["data"][k]) for k in groupKeys])
-        self.set_header("Content-type", "text/csv")
-        self.set_header("Content-Disposition", 'attachment; filename="%s.csv"' % md5(str(params)).hexdigest())
-        self.set_header("Content-Length", len(strData))
-        self.finish(strData)
+        return FileResponse(strData, str(params), ext="csv", cache=False)
 
-    @asyncGen
     def web_getPlotData(self):
-        callback = {}
-        retVal = self.__parseFormParams()
-        if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
+        if not (retVal := self.__parseFormParams())["OK"]:
+            return {"success": "false", "error": retVal["Message"]}
         params = retVal["Value"]
-        repClient = MonitoringClient()
-        retVal = yield self.threadTask(repClient.getReport, *params)
-        if not retVal["OK"]:
-            callback = {"success": "false", "error": retVal["Message"]}
-            self.finish(callback)
-        rawData = retVal["Value"]
-        self.finish(rawData["data"])
+        if not (retVal := MonitoringClient().getReport(*params))["OK"]:
+            return {"success": "false", "error": retVal["Message"]}
+        return retVal["Value"]["data"]
